<template>
    <div ref="datamodalfullscreen"
         :class="`absolute left-0 top-0 bg-gray-600 w-full max-h-screen  h-full z-40 transition duration-200 origin-center ${isShown ? 'opacity-100 visible' : 'opacity-0 invisible'}`">

        <div class="absolute right-2 top-2">
            <button @click="cancel" class="btn btn-circle">
                <svg xmlns="http://www.w3.org/2000/svg" class="h-6 w-6" fill="none" viewBox="0 0 24 24"
                     stroke="currentColor">
                    <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M6 18L18 6M6 6l12 12"/>
                </svg>
            </button>
        </div>
        <div v-if="chat.replyChat?.message" class="absolute overflow-hidden top-2 left-1/2 transform -translate-x-1/2 w-1/2 h-12 rounded-lg flex items-center p-2 bg-black bg-opacity-20 text-white z-20"
        >
          <span class="block whitespace-nowrap text-ellipsis overflow-hidden" v-html="helpers.whatsappFormatting(helpers.stripTags(chat.replyChat.message))"></span>
        </div>


        <div
                :class="`absolute max-h-full left-1/2 top-1/2 transition duration-300 ${isShown ? '-translate-y-1/2 opacity-100 visible' : 'translate-y-1/3 invisible opacity-0'}  origin-center transform -translate-x-1/2 w-full max-w-lg -translate-y-1/2 m-auto overflow-hidden rounded-lg`"
        >
            <div class="relative block h-full overflow-hidden p-4">
                <component :is="comps" @on-change="handleOnChange" :data="dataObject" @on-close="handleOnClose"/>
            </div>
        </div>
    </div>
</template>

<script setup lang="ts">
import Vue, {defineAsyncComponent, onBeforeMount, onMounted, onUnmounted, provide, ref, watch, watchEffect} from "vue";
import gsap from "gsap";
import useDetectOutsideClick from "../../composable/useDetectOutsideClick";
import {useChatListStore} from "../../stores/chat_list";
import IcLoading from "../Icon/IcLoading.vue";
import {inject} from 'vue'
import useDialog from "../../composable/useDialog";
import {useGeneralStore} from "../../stores/general";
import helpers from "../../utils/helpers";

const emit = defineEmits(['onSubmit', 'onClose'])

interface Props {
    isShow?: boolean,
    loading?: boolean,
    header?: string,
    buttonText?: string,
    component?: string,
}

let props = withDefaults(defineProps<Props>(), {
    isShow: false,
    loading: false,
    buttonText: null,
    component: null,
    header: "Modal header",
});
const useGeneral = useGeneralStore()
const chat = useChatListStore()
const resolved = ref()
const rejected = ref()
const isShown = ref(props.isShow)
const isLoading = ref(false)
const heading = ref(props.header)
const componentName = ref("ModalContentMedia")
const comps = ref()
const buttonString = ref(props.buttonText)
const onChangeData = ref()
const dataObject = ref(null)
const onClickAction = (e) => {
    emit("onSubmit", e)
}

const onCloseAction = (e) => {
    emit("onClose", e)
}

const handleOnChange = (e) => {
    onChangeData.value = {
        "data": e.data,
        "type": e.type,
    }
    const submittedData = {
        'confirm': false,
        'onchange': onChangeData.value.data,
        'submit_type': onChangeData.value.type,
        'event': e
    }
    useGeneral.dialogFullscreen.onChange = submittedData
    resolved.value(submittedData)
}

const handleOnClose = (e) => {
    if (e === true) {
        cancel(e)
    }
    // console.log(e, "isi on close")
}

onMounted(() => {
    dffcomp()
    useGeneral.dialogFullscreen.modal = open
})


const open = ({
                  title, btntext, component, data = null
              }) => {

    return new Promise((resolve, reject) => {
        resolved.value = resolve
        rejected.value = reject

        componentName.value = component
        dataObject.value = data
        isShown.value = true
        heading.value = title || heading.value
        buttonString.value = btntext
    }).then((res: any) => {
        return res
    }).finally(() => {
    })
}
const cancel = (e) => {
    emit("onClose", e)
    isShown.value = false
    resolved.value(false)
}
watch(() => componentName.value, (val) => {
    dffcomp()
})

const dffcomp = () => {
    comps.value = defineAsyncComponent(() => import(`@/components/Modal/Content/${componentName.value}.vue`))
}


const accept = (e) => {
    isLoading.value = true
    const submittedData = {
        'confirm': true,
        'submit_type': onChangeData.value.type,
        'onchange': onChangeData.value,
        'event': e
    }
    useGeneral.dialogFullscreen.onSubmit = submittedData
    resolved.value(submittedData)
    emit("onSubmit", submittedData)

    setTimeout(() => {
        isLoading.value = props.loading
        isShown.value = props.isShow
    }, 1500)

}

defineExpose({
    open
})

</script>